==> v2.2.0.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/model/Orders.java <==
package cn.kdan.pdf.tech.core.model;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class Orders implements Serializable {
    private Object id;

    private Integer appId;

    private Object subscriptionId;

    private String tradeNo;

    private String thirdOrderNo;

    private Double price;

    private Integer payment;

    private Integer status;

    private String result;

    private Date createdAt;

    private Date updatedAt;

    private String pagePayUrl;

    private BigDecimal invoiceNo;

    private String thirdTradeNo;

    private Integer productId;

    private BigDecimal discount;

    private BigDecimal reducedPrice;

    private Short isVpp;

    private static final long serialVersionUID = 1L;

    public Object getId() {
        return id;
    }

    public Orders withId(Object id) {
        this.setId(id);
        return this;
    }

    public void setId(Object id) {
        this.id = id;
    }

    public Integer getAppId() {
        return appId;
    }

    public Orders withAppId(Integer appId) {
        this.setAppId(appId);
        return this;
    }

    public void setAppId(Integer appId) {
        this.appId = appId;
    }

    public Object getSubscriptionId() {
        return subscriptionId;
    }

    public Orders withSubscriptionId(Object subscriptionId) {
        this.setSubscriptionId(subscriptionId);
        return this;
    }

    public void setSubscriptionId(Object subscriptionId) {
        this.subscriptionId = subscriptionId;
    }

    public String getTradeNo() {
        return tradeNo;
    }

    public Orders withTradeNo(String tradeNo) {
        this.setTradeNo(tradeNo);
        return this;
    }

    public void setTradeNo(String tradeNo) {
        this.tradeNo = tradeNo;
    }

    public String getThirdOrderNo() {
        return thirdOrderNo;
    }

    public Orders withThirdOrderNo(String thirdOrderNo) {
        this.setThirdOrderNo(thirdOrderNo);
        return this;
    }

    public void setThirdOrderNo(String thirdOrderNo) {
        this.thirdOrderNo = thirdOrderNo;
    }

    public Double getPrice() {
        return price;
    }

    public Orders withPrice(Double price) {
        this.setPrice(price);
        return this;
    }

    public void setPrice(Double price) {
        this.price = price;
    }

    public Integer getPayment() {
        return payment;
    }

    public Orders withPayment(Integer payment) {
        this.setPayment(payment);
        return this;
    }

    public void setPayment(Integer payment) {
        this.payment = payment;
    }

    public Integer getStatus() {
        return status;
    }

    public Orders withStatus(Integer status) {
        this.setStatus(status);
        return this;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getResult() {
        return result;
    }

    public Orders withResult(String result) {
        this.setResult(result);
        return this;
    }

    public void setResult(String result) {
        this.result = result;
    }

    public Date getCreatedAt() {
        return createdAt;
    }

    public Orders withCreatedAt(Date createdAt) {
        this.setCreatedAt(createdAt);
        return this;
    }

    public void setCreatedAt(Date createdAt) {
        this.createdAt = createdAt;
    }

    public Date getUpdatedAt() {
        return updatedAt;
    }

    public Orders withUpdatedAt(Date updatedAt) {
        this.setUpdatedAt(updatedAt);
        return this;
    }

    public void setUpdatedAt(Date updatedAt) {
        this.updatedAt = updatedAt;
    }

    public String getPagePayUrl() {
        return pagePayUrl;
    }

    public Orders withPagePayUrl(String pagePayUrl) {
        this.setPagePayUrl(pagePayUrl);
        return this;
    }

    public void setPagePayUrl(String pagePayUrl) {
        this.pagePayUrl = pagePayUrl;
    }

    public BigDecimal getInvoiceNo() {
        return invoiceNo;
    }

    public Orders withInvoiceNo(BigDecimal invoiceNo) {
        this.setInvoiceNo(invoiceNo);
        return this;
    }

    public void setInvoiceNo(BigDecimal invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public String getThirdTradeNo() {
        return thirdTradeNo;
    }

    public Orders withThirdTradeNo(String thirdTradeNo) {
        this.setThirdTradeNo(thirdTradeNo);
        return this;
    }

    public void setThirdTradeNo(String thirdTradeNo) {
        this.thirdTradeNo = thirdTradeNo;
    }

    public Integer getProductId() {
        return productId;
    }

    public Orders withProductId(Integer productId) {
        this.setProductId(productId);
        return this;
    }

    public void setProductId(Integer productId) {
        this.productId = productId;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public Orders withDiscount(BigDecimal discount) {
        this.setDiscount(discount);
        return this;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public BigDecimal getReducedPrice() {
        return reducedPrice;
    }

    public Orders withReducedPrice(BigDecimal reducedPrice) {
        this.setReducedPrice(reducedPrice);
        return this;
    }

    public void setReducedPrice(BigDecimal reducedPrice) {
        this.reducedPrice = reducedPrice;
    }

    public Short getIsVpp() {
        return isVpp;
    }

    public Orders withIsVpp(Short isVpp) {
        this.setIsVpp(isVpp);
        return this;
    }

    public void setIsVpp(Short isVpp) {
        this.isVpp = isVpp;
    }

    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Orders other = (Orders) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAppId() == null ? other.getAppId() == null : this.getAppId().equals(other.getAppId()))
            && (this.getSubscriptionId() == null ? other.getSubscriptionId() == null : this.getSubscriptionId().equals(other.getSubscriptionId()))
            && (this.getTradeNo() == null ? other.getTradeNo() == null : this.getTradeNo().equals(other.getTradeNo()))
            && (this.getThirdOrderNo() == null ? other.getThirdOrderNo() == null : this.getThirdOrderNo().equals(other.getThirdOrderNo()))
            && (this.getPrice() == null ? other.getPrice() == null : this.getPrice().equals(other.getPrice()))
            && (this.getPayment() == null ? other.getPayment() == null : this.getPayment().equals(other.getPayment()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getResult() == null ? other.getResult() == null : this.getResult().equals(other.getResult()))
            && (this.getCreatedAt() == null ? other.getCreatedAt() == null : this.getCreatedAt().equals(other.getCreatedAt()))
            && (this.getUpdatedAt() == null ? other.getUpdatedAt() == null : this.getUpdatedAt().equals(other.getUpdatedAt()))
            && (this.getPagePayUrl() == null ? other.getPagePayUrl() == null : this.getPagePayUrl().equals(other.getPagePayUrl()))
            && (this.getInvoiceNo() == null ? other.getInvoiceNo() == null : this.getInvoiceNo().equals(other.getInvoiceNo()))
            && (this.getThirdTradeNo() == null ? other.getThirdTradeNo() == null : this.getThirdTradeNo().equals(other.getThirdTradeNo()))
            && (this.getProductId() == null ? other.getProductId() == null : this.getProductId().equals(other.getProductId()))
            && (this.getDiscount() == null ? other.getDiscount() == null : this.getDiscount().equals(other.getDiscount()))
            && (this.getReducedPrice() == null ? other.getReducedPrice() == null : this.getReducedPrice().equals(other.getReducedPrice()))
            && (this.getIsVpp() == null ? other.getIsVpp() == null : this.getIsVpp().equals(other.getIsVpp()));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAppId() == null) ? 0 : getAppId().hashCode());
        result = prime * result + ((getSubscriptionId() == null) ? 0 : getSubscriptionId().hashCode());
        result = prime * result + ((getTradeNo() == null) ? 0 : getTradeNo().hashCode());
        result = prime * result + ((getThirdOrderNo() == null) ? 0 : getThirdOrderNo().hashCode());
        result = prime * result + ((getPrice() == null) ? 0 : getPrice().hashCode());
        result = prime * result + ((getPayment() == null) ? 0 : getPayment().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getResult() == null) ? 0 : getResult().hashCode());
        result = prime * result + ((getCreatedAt() == null) ? 0 : getCreatedAt().hashCode());
        result = prime * result + ((getUpdatedAt() == null) ? 0 : getUpdatedAt().hashCode());
        result = prime * result + ((getPagePayUrl() == null) ? 0 : getPagePayUrl().hashCode());
        result = prime * result + ((getInvoiceNo() == null) ? 0 : getInvoiceNo().hashCode());
        result = prime * result + ((getThirdTradeNo() == null) ? 0 : getThirdTradeNo().hashCode());
        result = prime * result + ((getProductId() == null) ? 0 : getProductId().hashCode());
        result = prime * result + ((getDiscount() == null) ? 0 : getDiscount().hashCode());
        result = prime * result + ((getReducedPrice() == null) ? 0 : getReducedPrice().hashCode());
        result = prime * result + ((getIsVpp() == null) ? 0 : getIsVpp().hashCode());
        return result;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", appId=").append(appId);
        sb.append(", subscriptionId=").append(subscriptionId);
        sb.append(", tradeNo=").append(tradeNo);
        sb.append(", thirdOrderNo=").append(thirdOrderNo);
        sb.append(", price=").append(price);
        sb.append(", payment=").append(payment);
        sb.append(", status=").append(status);
        sb.append(", result=").append(result);
        sb.append(", createdAt=").append(createdAt);
        sb.append(", updatedAt=").append(updatedAt);
        sb.append(", pagePayUrl=").append(pagePayUrl);
        sb.append(", invoiceNo=").append(invoiceNo);
        sb.append(", thirdTradeNo=").append(thirdTradeNo);
        sb.append(", productId=").append(productId);
        sb.append(", discount=").append(discount);
        sb.append(", reducedPrice=").append(reducedPrice);
        sb.append(", isVpp=").append(isVpp);
        sb.append(", serialVersionUID=").append(serialVersionUID);
        sb.append("]");
        return sb.toString();
    }
}

==> v3.0.1.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/model/Orders.java <==
package cn.kdan.pdf.tech.core.model;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class Orders implements Serializable {
    private String id;

    private Integer appId;

    private String subscriptionId;

    private String tradeNo;

    private String thirdOrderNo;

    private Double price;

    private Integer payment;

    private Integer status;

    private String result;

    private Date createdAt;

    private Date updatedAt;

    private String pagePayUrl;

    private BigDecimal invoiceNo;

    private String thirdTradeNo;

    private Integer productId;

    private BigDecimal discount;

    private BigDecimal reducedPrice;

    private Short isVpp;

    private Short type;

    private Short detailType;

    private String save;

    private Short discountType;

    private static final long serialVersionUID = 1L;

    public String getId() {
        return id;
    }

    public Orders withId(String id) {
        this.setId(id);
        return this;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Integer getAppId() {
        return appId;
    }

    public Orders withAppId(Integer appId) {
        this.setAppId(appId);
        return this;
    }

    public void setAppId(Integer appId) {
        this.appId = appId;
    }

    public String getSubscriptionId() {
        return subscriptionId;
    }

    public Orders withSubscriptionId(String subscriptionId) {
        this.setSubscriptionId(subscriptionId);
        return this;
    }

    public void setSubscriptionId(String subscriptionId) {
        this.subscriptionId = subscriptionId;
    }

    public String getTradeNo() {
        return tradeNo;
    }

    public Orders withTradeNo(String tradeNo) {
        this.setTradeNo(tradeNo);
        return this;
    }

    public void setTradeNo(String tradeNo) {
        this.tradeNo = tradeNo;
    }

    public String getThirdOrderNo() {
        return thirdOrderNo;
    }

    public Orders withThirdOrderNo(String thirdOrderNo) {
        this.setThirdOrderNo(thirdOrderNo);
        return this;
    }

    public void setThirdOrderNo(String thirdOrderNo) {
        this.thirdOrderNo = thirdOrderNo;
    }

    public Double getPrice() {
        return price;
    }

    public Orders withPrice(Double price) {
        this.setPrice(price);
        return this;
    }

    public void setPrice(Double price) {
        this.price = price;
    }

    public Integer getPayment() {
        return payment;
    }

    public Orders withPayment(Integer payment) {
        this.setPayment(payment);
        return this;
    }

    public void setPayment(Integer payment) {
        this.payment = payment;
    }

    public Integer getStatus() {
        return status;
    }

    public Orders withStatus(Integer status) {
        this.setStatus(status);
        return this;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getResult() {
        return result;
    }

    public Orders withResult(String result) {
        this.setResult(result);
        return this;
    }

    public void setResult(String result) {
        this.result = result;
    }

    public Date getCreatedAt() {
        return createdAt;
    }

    public Orders withCreatedAt(Date createdAt) {
        this.setCreatedAt(createdAt);
        return this;
    }

    public void setCreatedAt(Date createdAt) {
        this.createdAt = createdAt;
    }

    public Date getUpdatedAt() {
        return updatedAt;
    }

    public Orders withUpdatedAt(Date updatedAt) {
        this.setUpdatedAt(updatedAt);
        return this;
    }

    public void setUpdatedAt(Date updatedAt) {
        this.updatedAt = updatedAt;
    }

    public String getPagePayUrl() {
        return pagePayUrl;
    }

    public Orders withPagePayUrl(String pagePayUrl) {
        this.setPagePayUrl(pagePayUrl);
        return this;
    }

    public void setPagePayUrl(String pagePayUrl) {
        this.pagePayUrl = pagePayUrl;
    }

    public BigDecimal getInvoiceNo() {
        return invoiceNo;
    }

    public Orders withInvoiceNo(BigDecimal invoiceNo) {
        this.setInvoiceNo(invoiceNo);
        return this;
    }

    public void setInvoiceNo(BigDecimal invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public String getThirdTradeNo() {
        return thirdTradeNo;
    }

    public Orders withThirdTradeNo(String thirdTradeNo) {
        this.setThirdTradeNo(thirdTradeNo);
        return this;
    }

    public void setThirdTradeNo(String thirdTradeNo) {
        this.thirdTradeNo = thirdTradeNo;
    }

    public Integer getProductId() {
        return productId;
    }

    public Orders withProductId(Integer productId) {
        this.setProductId(productId);
        return this;
    }

    public void setProductId(Integer productId) {
        this.productId = productId;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public Orders withDiscount(BigDecimal discount) {
        this.setDiscount(discount);
        return this;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public BigDecimal getReducedPrice() {
        return reducedPrice;
    }

    public Orders withReducedPrice(BigDecimal reducedPrice) {
        this.setReducedPrice(reducedPrice);
        return this;
    }

    public void setReducedPrice(BigDecimal reducedPrice) {
        this.reducedPrice = reducedPrice;
    }

    public Short getIsVpp() {
        return isVpp;
    }

    public Orders withIsVpp(Short isVpp) {
        this.setIsVpp(isVpp);
        return this;
    }

    public void setIsVpp(Short isVpp) {
        this.isVpp = isVpp;
    }

    public Short getType() {
        return type;
    }

    public Orders withType(Short type) {
        this.setType(type);
        return this;
    }

    public void setType(Short type) {
        this.type = type;
    }

    public Short getDetailType() {
        return detailType;
    }

    public Orders withDetailType(Short detailType) {
        this.setDetailType(detailType);
        return this;
    }

    public void setDetailType(Short detailType) {
        this.detailType = detailType;
    }

    public String getSave() {
        return save;
    }

    public Orders withSave(String save) {
        this.setSave(save);
        return this;
    }

    public void setSave(String save) {
        this.save = save;
    }

    public Short getDiscountType() {
        return discountType;
    }

    public Orders withDiscountType(Short discountType) {
        this.setDiscountType(discountType);
        return this;
    }

    public void setDiscountType(Short discountType) {
        this.discountType = discountType;
    }

    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Orders other = (Orders) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAppId() == null ? other.getAppId() == null : this.getAppId().equals(other.getAppId()))
            && (this.getSubscriptionId() == null ? other.getSubscriptionId() == null : this.getSubscriptionId().equals(other.getSubscriptionId()))
            && (this.getTradeNo() == null ? other.getTradeNo() == null : this.getTradeNo().equals(other.getTradeNo()))
            && (this.getThirdOrderNo() == null ? other.getThirdOrderNo() == null : this.getThirdOrderNo().equals(other.getThirdOrderNo()))
            && (this.getPrice() == null ? other.getPrice() == null : this.getPrice().equals(other.getPrice()))
            && (this.getPayment() == null ? other.getPayment() == null : this.getPayment().equals(other.getPayment()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getResult() == null ? other.getResult() == null : this.getResult().equals(other.getResult()))
            && (this.getCreatedAt() == null ? other.getCreatedAt() == null : this.getCreatedAt().equals(other.getCreatedAt()))
            && (this.getUpdatedAt() == null ? other.getUpdatedAt() == null : this.getUpdatedAt().equals(other.getUpdatedAt()))
            && (this.getPagePayUrl() == null ? other.getPagePayUrl() == null : this.getPagePayUrl().equals(other.getPagePayUrl()))
            && (this.getInvoiceNo() == null ? other.getInvoiceNo() == null : this.getInvoiceNo().equals(other.getInvoiceNo()))
            && (this.getThirdTradeNo() == null ? other.getThirdTradeNo() == null : this.getThirdTradeNo().equals(other.getThirdTradeNo()))
            && (this.getProductId() == null ? other.getProductId() == null : this.getProductId().equals(other.getProductId()))
            && (this.getDiscount() == null ? other.getDiscount() == null : this.getDiscount().equals(other.getDiscount()))
            && (this.getReducedPrice() == null ? other.getReducedPrice() == null : this.getReducedPrice().equals(other.getReducedPrice()))
            && (this.getIsVpp() == null ? other.getIsVpp() == null : this.getIsVpp().equals(other.getIsVpp()))
            && (this.getType() == null ? other.getType() == null : this.getType().equals(other.getType()))
            && (this.getDetailType() == null ? other.getDetailType() == null : this.getDetailType().equals(other.getDetailType()))
            && (this.getSave() == null ? other.getSave() == null : this.getSave().equals(other.getSave()))
            && (this.getDiscountType() == null ? other.getDiscountType() == null : this.getDiscountType().equals(other.getDiscountType()));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAppId() == null) ? 0 : getAppId().hashCode());
        result = prime * result + ((getSubscriptionId() == null) ? 0 : getSubscriptionId().hashCode());
        result = prime * result + ((getTradeNo() == null) ? 0 : getTradeNo().hashCode());
        result = prime * result + ((getThirdOrderNo() == null) ? 0 : getThirdOrderNo().hashCode());
        result = prime * result + ((getPrice() == null) ? 0 : getPrice().hashCode());
        result = prime * result + ((getPayment() == null) ? 0 : getPayment().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getResult() == null) ? 0 : getResult().hashCode());
        result = prime * result + ((getCreatedAt() == null) ? 0 : getCreatedAt().hashCode());
        result = prime * result + ((getUpdatedAt() == null) ? 0 : getUpdatedAt().hashCode());
        result = prime * result + ((getPagePayUrl() == null) ? 0 : getPagePayUrl().hashCode());
        result = prime * result + ((getInvoiceNo() == null) ? 0 : getInvoiceNo().hashCode());
        result = prime * result + ((getThirdTradeNo() == null) ? 0 : getThirdTradeNo().hashCode());
        result = prime * result + ((getProductId() == null) ? 0 : getProductId().hashCode());
        result = prime * result + ((getDiscount() == null) ? 0 : getDiscount().hashCode());
        result = prime * result + ((getReducedPrice() == null) ? 0 : getReducedPrice().hashCode());
        result = prime * result + ((getIsVpp() == null) ? 0 : getIsVpp().hashCode());
        result = prime * result + ((getType() == null) ? 0 : getType().hashCode());
        result = prime * result + ((getDetailType() == null) ? 0 : getDetailType().hashCode());
        result = prime * result + ((getSave() == null) ? 0 : getSave().hashCode());
        result = prime * result + ((getDiscountType() == null) ? 0 : getDiscountType().hashCode());
        return result;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", appId=").append(appId);
        sb.append(", subscriptionId=").append(subscriptionId);
        sb.append(", tradeNo=").append(tradeNo);
        sb.append(", thirdOrderNo=").append(thirdOrderNo);
        sb.append(", price=").append(price);
        sb.append(", payment=").append(payment);
        sb.append(", status=").append(status);
        sb.append(", result=").append(result);
        sb.append(", createdAt=").append(createdAt);
        sb.append(", updatedAt=").append(updatedAt);
        sb.append(", pagePayUrl=").append(pagePayUrl);
        sb.append(", invoiceNo=").append(invoiceNo);
        sb.append(", thirdTradeNo=").append(thirdTradeNo);
        sb.append(", productId=").append(productId);
        sb.append(", discount=").append(discount);
        sb.append(", reducedPrice=").append(reducedPrice);
        sb.append(", isVpp=").append(isVpp);
        sb.append(", type=").append(type);
        sb.append(", detailType=").append(detailType);
        sb.append(", save=").append(save);
        sb.append(", discountType=").append(discountType);
        sb.append(", serialVersionUID=").append(serialVersionUID);
        sb.append("]");
        return sb.toString();
    }
}
